@@ -287,7 +287,7 @@ class LevelController:
         self.parent.level_view.update()
 
     def display_header_editor(self):
-        header_editor = HeaderEditor(None, self.level_ref)
+        header_editor = HeaderEditor(self.parent, self.level_ref)  # type: ignore
         header_editor.tab_widget.setCurrentIndex(3)
         header_editor.exec_()
 
@@ -295,7 +295,10 @@ class LevelController:
         index = self.parent.jump_list.currentIndex().row()
 
         updated_jump = JumpEditor.edit_jump(
-            None, self.level_ref.level.jumps[index], not self.level_ref.level.is_vertical
+            self.parent,  # type: ignore
+            self.level_ref.level.jumps[index],
+            not self.level_ref.level.is_vertical,
+            (self.level_ref.level.length // 0x10) - 1,
         )
 
         self.on_jump_edited(updated_jump)
